# rotel-sdk 🌶️ 🍅

Python package for the Rotel processor SDK.

## Description

This package provides type hints for the Rotel processor SDK and is intended for use with your Python LSP (pyright).

| Telemetry Type | Support     |
|----------------|-------------|
| Traces         | Alpha       |
| Metrics        | Coming Soon |
| Logs           | Coming Soon |



